package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Object;
import cn.com.infosec.asn1.ASN1OutputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.misc.MiscObjectIdentifiers;
import cn.com.infosec.asn1.misc.NetscapeCertType;
import cn.com.infosec.asn1.misc.NetscapeRevocationURL;
import cn.com.infosec.asn1.misc.VerisignCzagExtension;
import cn.com.infosec.asn1.util.ASN1Dump;
import cn.com.infosec.asn1.x509.BasicConstraints;
import cn.com.infosec.asn1.x509.KeyUsage;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Extension;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import cn.com.infosec.util.Arrays;
import cn.com.infosec.util.encoders.Hex;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.InvalidKeyException;
import java.security.Principal;
import java.security.Provider;
import java.security.PublicKey;
import java.security.Security;
import java.security.Signature;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import javax.security.auth.x500.X500Principal;

public class X509CertificateObject extends X509Certificate implements PKCS12BagAttributeCarrier {
   private X509CertificateStructure c;
   private BasicConstraints basicConstraints;
   private boolean[] keyUsage;
   private PKCS12BagAttributeCarrier attrCarrier;

   public X509CertificateObject(X509CertificateStructure c) {
      X509CertificateObject var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.c = c;

      boolean var10001;
      Exception var19;
      byte[] c1;
      Exception var23;
      byte[] var24;
      label119: {
         label123: {
            try {
               var24 = var10000.getExtensionBytes("2.5.29.19");
            } catch (Exception var18) {
               var23 = var18;
               var10001 = false;
               break label123;
            }

            c1 = var24;
            if (var24 == null) {
               break label119;
            }

            try {
               this.basicConstraints = BasicConstraints.getInstance(ASN1Object.fromByteArray(c1));
               break label119;
            } catch (Exception var17) {
               var23 = var17;
               var10001 = false;
            }
         }

         var19 = var23;
         throw new CertificateParsingException("cannot construct BasicConstraints: " + var19);
      }

      label108: {
         try {
            var24 = this.getExtensionBytes("2.5.29.15");
         } catch (Exception var16) {
            var23 = var16;
            var10001 = false;
            break label108;
         }

         c1 = var24;
         if (var24 != null) {
            label124: {
               DERBitString var26;
               try {
                  var26 = DERBitString.getInstance(ASN1Object.fromByteArray(c1));
               } catch (Exception var14) {
                  var23 = var14;
                  var10001 = false;
                  break label124;
               }

               DERBitString c2 = var26;

               try {
                  var24 = var26.getBytes();
               } catch (Exception var13) {
                  var23 = var13;
                  var10001 = false;
                  break label124;
               }

               byte[] var2 = var24;

               int var28;
               try {
                  var28 = var24.length;
               } catch (Exception var12) {
                  var23 = var12;
                  var10001 = false;
                  break label124;
               }

               int var27;
               try {
                  var27 = c2.getPadBits();
               } catch (Exception var11) {
                  var23 = var11;
                  var10001 = false;
                  break label124;
               }

               int var3;
               int c3;
               if ((c3 = var28 * 8 - var27) < 9) {
                  var3 = 9;
               } else {
                  var3 = c3;
               }

               try {
                  this.keyUsage = new boolean[var3];
               } catch (Exception var10) {
                  var23 = var10;
                  var10001 = false;
                  break label124;
               }

               var3 = 0;

               while(true) {
                  if (var3 == c3) {
                     return;
                  }

                  boolean[] var10002;
                  try {
                     var24 = var2;
                     var27 = var3;
                     var10002 = this.keyUsage;
                  } catch (Exception var9) {
                     var23 = var9;
                     var10001 = false;
                     break;
                  }

                  boolean[] var4 = var10002;

                  byte var29;
                  try {
                     var29 = var24[var27 / 8];
                  } catch (Exception var8) {
                     var23 = var8;
                     var10001 = false;
                     break;
                  }

                  int var25;
                  try {
                     var25 = var3 % 8;
                  } catch (Exception var7) {
                     var23 = var7;
                     var10001 = false;
                     break;
                  }

                  boolean var5;
                  if ((var29 & 128 >>> var25) != 0) {
                     var5 = true;
                  } else {
                     var5 = false;
                  }

                  try {
                     var4[var3] = var5;
                  } catch (Exception var6) {
                     var23 = var6;
                     var10001 = false;
                     break;
                  }

                  ++var3;
               }
            }
         } else {
            try {
               this.keyUsage = null;
               return;
            } catch (Exception var15) {
               var23 = var15;
               var10001 = false;
            }
         }
      }

      var19 = var23;
      throw new CertificateParsingException("cannot construct KeyUsage: " + var19);
   }

   private byte[] getExtensionBytes(String oid) {
      X509Extensions var2;
      if ((var2 = this.c.getTBSCertificate().getExtensions()) != null) {
         X509Extensions var10000 = var2;
         DERObjectIdentifier var3;
         var3 = new DERObjectIdentifier.<init>(oid);
         X509Extension var4;
         if ((var4 = var10000.getExtension(var3)) != null) {
            return var4.getValue().getOctets();
         }
      }

      return null;
   }

   private void checkSignature(PublicKey key, Signature signature) {
      if (this.c.getSignatureAlgorithm().equals(this.c.getTBSCertificate().getSignature())) {
         X509SignatureUtil.setSignatureParameters(signature, this.c.getSignatureAlgorithm().getParameters());
         signature.initVerify(key);
         signature.update(this.getTBSCertificate());
         if (!signature.verify(this.getSignature())) {
            throw new InvalidKeyException("Public key presented not for certificate signature");
         }
      } else {
         throw new CertificateException("signature algorithm in TBS cert not same as outer cert");
      }
   }

   public void checkValidity() {
      X509CertificateObject var10000 = this;
      Date var1;
      var1 = new Date.<init>();
      var10000.checkValidity(var1);
   }

   public void checkValidity(Date date) {
      if (date.getTime() <= this.getNotAfter().getTime()) {
         if (date.getTime() < this.getNotBefore().getTime()) {
            throw new CertificateNotYetValidException("certificate not valid till " + this.c.getStartDate().getTime());
         }
      } else {
         throw new CertificateExpiredException("certificate expired on " + this.c.getEndDate().getTime());
      }
   }

   public int getVersion() {
      return this.c.getVersion();
   }

   public BigInteger getSerialNumber() {
      return this.c.getSerialNumber().getValue();
   }

   public Principal getIssuerDN() {
      return new X509Principal(this.c.getIssuer());
   }

   public X500Principal getIssuerX500Principal() {
      ByteArrayOutputStream var10000;
      boolean var10001;
      try {
         var10000 = new ByteArrayOutputStream;
      } catch (IOException var4) {
         var10001 = false;
         throw new IllegalStateException("can't encode issuer DN");
      }

      ByteArrayOutputStream var1 = var10000;

      ASN1OutputStream var5;
      try {
         var10000.<init>();
         var5 = new ASN1OutputStream;
      } catch (IOException var3) {
         var10001 = false;
         throw new IllegalStateException("can't encode issuer DN");
      }

      ASN1OutputStream var6 = var5;

      try {
         var6.<init>(var1);
         var5.writeObject(this.c.getIssuer());
         return new X500Principal(var1.toByteArray());
      } catch (IOException var2) {
         var10001 = false;
         throw new IllegalStateException("can't encode issuer DN");
      }
   }

   public Principal getSubjectDN() {
      return new X509Principal(this.c.getSubject());
   }

   public X500Principal getSubjectX500Principal() {
      ByteArrayOutputStream var10000;
      boolean var10001;
      try {
         var10000 = new ByteArrayOutputStream;
      } catch (IOException var4) {
         var10001 = false;
         throw new IllegalStateException("can't encode issuer DN");
      }

      ByteArrayOutputStream var1 = var10000;

      ASN1OutputStream var5;
      try {
         var10000.<init>();
         var5 = new ASN1OutputStream;
      } catch (IOException var3) {
         var10001 = false;
         throw new IllegalStateException("can't encode issuer DN");
      }

      ASN1OutputStream var6 = var5;

      try {
         var6.<init>(var1);
         var5.writeObject(this.c.getSubject());
         return new X500Principal(var1.toByteArray());
      } catch (IOException var2) {
         var10001 = false;
         throw new IllegalStateException("can't encode issuer DN");
      }
   }

   public Date getNotBefore() {
      return this.c.getStartDate().getDate();
   }

   public Date getNotAfter() {
      return this.c.getEndDate().getDate();
   }

   public byte[] getTBSCertificate() {
      ByteArrayOutputStream var1;
      ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
      var10000.<init>();
      X509CertificateObject var10002 = this;
      DEROutputStream var10001 = new DEROutputStream(var1);

      try {
         var10001.writeObject(var10002.c.getTBSCertificate());
         return var10000.toByteArray();
      } catch (IOException var2) {
         throw new CertificateEncodingException(var2.toString());
      }
   }

   public byte[] getSignature() {
      return this.c.getSignature().getBytes();
   }

   public String getSigAlgName() {
      Provider var1;
      String var4;
      if ((var1 = Security.getProvider("INFOSEC")) != null && (var4 = var1.getProperty("Alg.Alias.Signature." + this.getSigAlgOID())) != null) {
         return var4;
      } else {
         Provider[] var5 = Security.getProviders();

         for(int var2 = 0; var2 != var5.length; ++var2) {
            String var3;
            if ((var3 = var5[var2].getProperty("Alg.Alias.Signature." + this.getSigAlgOID())) != null) {
               return var3;
            }
         }

         return this.getSigAlgOID();
      }
   }

   public String getSigAlgOID() {
      return this.c.getSignatureAlgorithm().getObjectId().getId();
   }

   public byte[] getSigAlgParams() {
      return this.c.getSignatureAlgorithm().getParameters() != null ? this.c.getSignatureAlgorithm().getParameters().getDERObject().getDEREncoded() : null;
   }

   public boolean[] getIssuerUniqueID() {
      DERBitString var5;
      if ((var5 = this.c.getTBSCertificate().getIssuerUniqueId()) != null) {
         byte[] var1;
         int var6;
         boolean[] var2 = new boolean[var6 = (var1 = var5.getBytes()).length * 8 - var5.getPadBits()];

         for(int var3 = 0; var3 != var6; ++var3) {
            boolean var4;
            if ((var1[var3 / 8] & 128 >>> var3 % 8) != 0) {
               var4 = true;
            } else {
               var4 = false;
            }

            var2[var3] = var4;
         }

         return var2;
      } else {
         return null;
      }
   }

   public boolean[] getSubjectUniqueID() {
      DERBitString var5;
      if ((var5 = this.c.getTBSCertificate().getSubjectUniqueId()) != null) {
         byte[] var1;
         int var6;
         boolean[] var2 = new boolean[var6 = (var1 = var5.getBytes()).length * 8 - var5.getPadBits()];

         for(int var3 = 0; var3 != var6; ++var3) {
            boolean var4;
            if ((var1[var3 / 8] & 128 >>> var3 % 8) != 0) {
               var4 = true;
            } else {
               var4 = false;
            }

            var2[var3] = var4;
         }

         return var2;
      } else {
         return null;
      }
   }

   public boolean[] getKeyUsage() {
      return this.keyUsage;
   }

   public List getExtendedKeyUsage() {
      byte[] var9;
      if ((var9 = this.getExtensionBytes("2.5.29.37")) != null) {
         ASN1Sequence var10000;
         boolean var10001;
         try {
            var10000 = (ASN1Sequence)(new ASN1InputStream(var9)).readObject();
         } catch (Exception var8) {
            var10001 = false;
            throw new CertificateParsingException("error processing extended key usage extension");
         }

         ASN1Sequence var10 = var10000;

         ArrayList var11;
         try {
            var11 = new ArrayList;
         } catch (Exception var7) {
            var10001 = false;
            throw new CertificateParsingException("error processing extended key usage extension");
         }

         ArrayList var1 = var11;

         try {
            var11.<init>();
         } catch (Exception var6) {
            var10001 = false;
            throw new CertificateParsingException("error processing extended key usage extension");
         }

         int var2 = 0;

         while(true) {
            int var12;
            int var13;
            try {
               var12 = var2;
               var13 = var10.size();
            } catch (Exception var4) {
               var10001 = false;
               break;
            }

            if (var12 == var13) {
               try {
                  return Collections.unmodifiableList(var1);
               } catch (Exception var3) {
                  var10001 = false;
                  break;
               }
            }

            try {
               var1.add(((DERObjectIdentifier)var10.getObjectAt(var2)).getId());
            } catch (Exception var5) {
               var10001 = false;
               break;
            }

            ++var2;
         }

         throw new CertificateParsingException("error processing extended key usage extension");
      } else {
         return null;
      }
   }

   public int getBasicConstraints() {
      BasicConstraints var1;
      if ((var1 = this.basicConstraints) != null) {
         if (var1.isCA()) {
            return this.basicConstraints.getPathLenConstraint() == null ? Integer.MAX_VALUE : this.basicConstraints.getPathLenConstraint().intValue();
         } else {
            return -1;
         }
      } else {
         return -1;
      }
   }

   public Set getCriticalExtensionOIDs() {
      if (this.getVersion() == 3) {
         X509CertificateObject var10000 = this;
         HashSet var4;
         var4 = new HashSet.<init>();
         X509Extensions var1;
         if ((var1 = var10000.c.getTBSCertificate().getExtensions()) != null) {
            Enumeration var2 = var1.oids();

            while(var2.hasMoreElements()) {
               DERObjectIdentifier var3;
               if (var1.getExtension(var3 = (DERObjectIdentifier)var2.nextElement()).isCritical()) {
                  var4.add(var3.getId());
               }
            }

            return var4;
         }
      }

      return null;
   }

   public byte[] getExtensionValue(String oid) {
      X509Extensions var3;
      if ((var3 = this.c.getTBSCertificate().getExtensions()) != null) {
         X509Extensions var10000 = var3;
         DERObjectIdentifier var4;
         var4 = new DERObjectIdentifier.<init>(oid);
         X509Extension var5;
         if ((var5 = var10000.getExtension(var4)) != null) {
            try {
               return var5.getValue().getEncoded();
            } catch (Exception var2) {
               throw new IllegalStateException("error parsing " + var2.toString());
            }
         }
      }

      return null;
   }

   public Set getNonCriticalExtensionOIDs() {
      if (this.getVersion() == 3) {
         X509CertificateObject var10000 = this;
         HashSet var4;
         var4 = new HashSet.<init>();
         X509Extensions var1;
         if ((var1 = var10000.c.getTBSCertificate().getExtensions()) != null) {
            Enumeration var2 = var1.oids();

            while(var2.hasMoreElements()) {
               DERObjectIdentifier var3;
               if (!var1.getExtension(var3 = (DERObjectIdentifier)var2.nextElement()).isCritical()) {
                  var4.add(var3.getId());
               }
            }

            return var4;
         }
      }

      return null;
   }

   public boolean hasUnsupportedCriticalExtension() {
      X509Extensions var4;
      if (this.getVersion() == 3 && (var4 = this.c.getTBSCertificate().getExtensions()) != null) {
         Enumeration var1 = var4.oids();

         while(var1.hasMoreElements()) {
            DERObjectIdentifier var2;
            String var3;
            if (!(var3 = (var2 = (DERObjectIdentifier)var1.nextElement()).getId()).equals(RFC3280CertPathUtilities.KEY_USAGE) && !var3.equals(RFC3280CertPathUtilities.CERTIFICATE_POLICIES) && !var3.equals(RFC3280CertPathUtilities.POLICY_MAPPINGS) && !var3.equals(RFC3280CertPathUtilities.INHIBIT_ANY_POLICY) && !var3.equals(RFC3280CertPathUtilities.CRL_DISTRIBUTION_POINTS) && !var3.equals(RFC3280CertPathUtilities.ISSUING_DISTRIBUTION_POINT) && !var3.equals(RFC3280CertPathUtilities.DELTA_CRL_INDICATOR) && !var3.equals(RFC3280CertPathUtilities.POLICY_CONSTRAINTS) && !var3.equals(RFC3280CertPathUtilities.BASIC_CONSTRAINTS) && !var3.equals(RFC3280CertPathUtilities.SUBJECT_ALTERNATIVE_NAME) && !var3.equals(RFC3280CertPathUtilities.NAME_CONSTRAINTS) && var4.getExtension(var2).isCritical()) {
               return true;
            }
         }
      }

      return false;
   }

   public PublicKey getPublicKey() {
      return JDKKeyFactory.createPublicKeyFromPublicKeyInfo(this.c.getSubjectPublicKeyInfo());
   }

   public byte[] getEncoded() {
      ByteArrayOutputStream var1;
      ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
      var10000.<init>();
      X509CertificateObject var10002 = this;
      DEROutputStream var10001 = new DEROutputStream(var1);

      try {
         var10001.writeObject(var10002.c);
         return var10000.toByteArray();
      } catch (IOException var2) {
         throw new CertificateEncodingException(var2.toString());
      }
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof Certificate)) {
         return false;
      } else {
         X509CertificateObject var10000 = this;
         Certificate var3 = (Certificate)o;

         try {
            return Arrays.areEqual(var10000.getEncoded(), var3.getEncoded());
         } catch (CertificateEncodingException var2) {
            return false;
         }
      }
   }

   public int hashCode() {
      byte[] var10000;
      boolean var10001;
      try {
         var10000 = this.getEncoded();
      } catch (CertificateEncodingException var6) {
         var10001 = false;
         return 0;
      }

      byte[] var7 = var10000;
      int var1 = 0;
      int var2 = 0;

      while(true) {
         int var8;
         int var9;
         try {
            var8 = var2;
            var9 = var7.length;
         } catch (CertificateEncodingException var5) {
            var10001 = false;
            break;
         }

         if (var8 == var9) {
            return var1;
         }

         byte var10;
         try {
            var8 = var1;
            var10 = var7[var2];
         } catch (CertificateEncodingException var4) {
            var10001 = false;
            break;
         }

         int var10002;
         try {
            var10002 = var2 % 4;
         } catch (CertificateEncodingException var3) {
            var10001 = false;
            break;
         }

         var1 = var8 ^ (var10 & 255) << var10002;
         ++var2;
      }

      return 0;
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }

   public String toString() {
      StringBuffer var1;
      StringBuffer var10000 = var1 = new StringBuffer;
      var1.<init>();
      String var2 = System.getProperty("line.separator");
      var1.append("  [0]         Version: ").append(this.getVersion()).append(var2);
      var1.append("         SerialNumber: ").append(this.getSerialNumber()).append(var2);
      var1.append("             IssuerDN: ").append(this.getIssuerDN()).append(var2);
      var1.append("           Start Date: ").append(this.getNotBefore()).append(var2);
      var1.append("           Final Date: ").append(this.getNotAfter()).append(var2);
      var1.append("            SubjectDN: ").append(this.getSubjectDN()).append(var2);
      var1.append("           Public Key: ").append(this.getPublicKey()).append(var2);
      var1.append("  Signature Algorithm: ").append(this.getSigAlgName()).append(var2);
      byte[] var3 = this.getSignature();
      var10000.append("            Signature: ").append(new String(Hex.encode(var3, 0, 20))).append(var2);

      for(int var4 = 20; var4 < var3.length; var4 += 20) {
         if (var4 < var3.length - 20) {
            var1.append("                       ").append(new String(Hex.encode(var3, var4, 20))).append(var2);
         } else {
            var1.append("                       ").append(new String(Hex.encode(var3, var4, var3.length - var4))).append(var2);
         }
      }

      X509Extensions var20;
      if ((var20 = this.c.getTBSCertificate().getExtensions()) != null) {
         Enumeration var21;
         if ((var21 = var20.oids()).hasMoreElements()) {
            var1.append("       Extensions: \n");
         }

         while(true) {
            while(true) {
               while(var21.hasMoreElements()) {
                  X509Extension var5;
                  DERObjectIdentifier var22;
                  if ((var5 = var20.getExtension(var22 = (DERObjectIdentifier)var21.nextElement())).getValue() != null) {
                     DERObjectIdentifier var23 = var22;
                     byte[] var6 = var5.getValue().getOctets();
                     ASN1InputStream var7;
                     var7 = new ASN1InputStream.<init>(var6);
                     var1.append("                       critical(").append(var5.isCritical()).append(") ");

                     label108: {
                        boolean var10001;
                        boolean var24;
                        try {
                           var24 = var23.equals(X509Extensions.BasicConstraints);
                        } catch (Exception var19) {
                           var10001 = false;
                           break label108;
                        }

                        if (var24) {
                           try {
                              var1.append(new BasicConstraints((ASN1Sequence)var7.readObject())).append(var2);
                              continue;
                           } catch (Exception var8) {
                              var10001 = false;
                           }
                        } else {
                           label104: {
                              try {
                                 var24 = var22.equals(X509Extensions.KeyUsage);
                              } catch (Exception var18) {
                                 var10001 = false;
                                 break label104;
                              }

                              if (var24) {
                                 try {
                                    var1.append(new KeyUsage((DERBitString)var7.readObject())).append(var2);
                                    continue;
                                 } catch (Exception var9) {
                                    var10001 = false;
                                 }
                              } else {
                                 label100: {
                                    try {
                                       var24 = var22.equals(MiscObjectIdentifiers.netscapeCertType);
                                    } catch (Exception var17) {
                                       var10001 = false;
                                       break label100;
                                    }

                                    if (var24) {
                                       try {
                                          var1.append(new NetscapeCertType((DERBitString)var7.readObject())).append(var2);
                                          continue;
                                       } catch (Exception var10) {
                                          var10001 = false;
                                       }
                                    } else {
                                       label96: {
                                          try {
                                             var24 = var22.equals(MiscObjectIdentifiers.netscapeRevocationURL);
                                          } catch (Exception var16) {
                                             var10001 = false;
                                             break label96;
                                          }

                                          if (var24) {
                                             try {
                                                var1.append(new NetscapeRevocationURL((DERIA5String)var7.readObject())).append(var2);
                                                continue;
                                             } catch (Exception var11) {
                                                var10001 = false;
                                             }
                                          } else {
                                             label92: {
                                                try {
                                                   var24 = var22.equals(MiscObjectIdentifiers.verisignCzagExtension);
                                                } catch (Exception var15) {
                                                   var10001 = false;
                                                   break label92;
                                                }

                                                if (var24) {
                                                   try {
                                                      var1.append(new VerisignCzagExtension((DERIA5String)var7.readObject())).append(var2);
                                                      continue;
                                                   } catch (Exception var12) {
                                                      var10001 = false;
                                                   }
                                                } else {
                                                   label127: {
                                                      try {
                                                         var10000 = var1;
                                                         var1.append(var22.getId());
                                                      } catch (Exception var14) {
                                                         var10001 = false;
                                                         break label127;
                                                      }

                                                      try {
                                                         var10000.append(" value = ").append(ASN1Dump.dumpAsString(var7.readObject())).append(var2);
                                                         continue;
                                                      } catch (Exception var13) {
                                                         var10001 = false;
                                                      }
                                                   }
                                                }
                                             }
                                          }
                                       }
                                    }
                                 }
                              }
                           }
                        }
                     }

                     var1.append(var22.getId());
                     var1.append(" value = ").append("*****").append(var2);
                  } else {
                     var1.append(var2);
                  }
               }

               return var1.toString();
            }
         }
      } else {
         return var1.toString();
      }
   }

   public final void verify(PublicKey key) {
      String var2;
      String var10000 = var2 = X509SignatureUtil.getSignatureName(this.c.getSignatureAlgorithm());

      Signature var5;
      label13: {
         Signature var4;
         try {
            var4 = Signature.getInstance(var10000, "INFOSEC");
         } catch (Exception var3) {
            var5 = Signature.getInstance(var2);
            break label13;
         }

         var5 = var4;
      }

      this.checkSignature(key, var5);
   }

   public final void verify(PublicKey key, String sigProvider) {
      this.checkSignature(key, Signature.getInstance(X509SignatureUtil.getSignatureName(this.c.getSignatureAlgorithm()), sigProvider));
   }
}
